# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: messaging_gateway.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

try:
    from google.protobuf import runtime_version as _runtime_version

    _runtime_version.ValidateProtobufRuntimeVersion(
        _runtime_version.Domain.PUBLIC,
        5,
        29,
        0,
        "",
        "messaging_gateway.proto",
    )
except ImportError:
    pass  # older protobuf has no runtime_version
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x17messaging_gateway.proto\x12\x12\x63law_swarm.gateway"\xf4\x01\n\x0eUnifiedMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\x08platform\x18\x02 \x01(\x0e\x32\x1c.claw_swarm.gateway.Platform\x12\x12\n\nchannel_id\x18\x03 \x01(\t\x12\x11\n\tthread_id\x18\x04 \x01(\t\x12\x11\n\tsender_id\x18\x05 \x01(\t\x12\x15\n\rsender_handle\x18\x06 \x01(\t\x12\x0c\n\x04text\x18\x07 \x01(\t\x12\x17\n\x0f\x61ttachment_urls\x18\x08 \x03(\t\x12\x18\n\x10timestamp_utc_ms\x18\t \x01(\x03\x12\x14\n\x0craw_metadata\x18\n \x01(\x0c"|\n\x13PollMessagesRequest\x12/\n\tplatforms\x18\x01 \x03(\x0e\x32\x1c.claw_swarm.gateway.Platform\x12\x1e\n\x16since_timestamp_utc_ms\x18\x02 \x01(\x03\x12\x14\n\x0cmax_messages\x18\x03 \x01(\x05"L\n\x14PollMessagesResponse\x12\x34\n\x08messages\x18\x01 \x03(\x0b\x32".claw_swarm.gateway.UnifiedMessage"H\n\x15StreamMessagesRequest\x12/\n\tplatforms\x18\x01 \x03(\x0e\x32\x1c.claw_swarm.gateway.Platform"\x0f\n\rHealthRequest"-\n\x0eHealthResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\x0f\n\x07version\x18\x02 \x01(\t*M\n\x08Platform\x12\x18\n\x14PLATFORM_UNSPECIFIED\x10\x00\x12\x0c\n\x08TELEGRAM\x10\x01\x12\x0b\n\x07\x44ISCORD\x10\x02\x12\x0c\n\x08WHATSAPP\x10\x03\x32\xa9\x02\n\x10MessagingGateway\x12\x61\n\x0cPollMessages\x12\'.claw_swarm.gateway.PollMessagesRequest\x1a(.claw_swarm.gateway.PollMessagesResponse\x12\x61\n\x0eStreamMessages\x12).claw_swarm.gateway.StreamMessagesRequest\x1a".claw_swarm.gateway.UnifiedMessage0\x01\x12O\n\x06Health\x12!.claw_swarm.gateway.HealthRequest\x1a".claw_swarm.gateway.HealthResponseb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "messaging_gateway_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals["_PLATFORM"]._serialized_start = 636
    _globals["_PLATFORM"]._serialized_end = 713
    _globals["_UNIFIEDMESSAGE"]._serialized_start = 48
    _globals["_UNIFIEDMESSAGE"]._serialized_end = 292
    _globals["_POLLMESSAGESREQUEST"]._serialized_start = 294
    _globals["_POLLMESSAGESREQUEST"]._serialized_end = 418
    _globals["_POLLMESSAGESRESPONSE"]._serialized_start = 420
    _globals["_POLLMESSAGESRESPONSE"]._serialized_end = 496
    _globals["_STREAMMESSAGESREQUEST"]._serialized_start = 498
    _globals["_STREAMMESSAGESREQUEST"]._serialized_end = 570
    _globals["_HEALTHREQUEST"]._serialized_start = 572
    _globals["_HEALTHREQUEST"]._serialized_end = 587
    _globals["_HEALTHRESPONSE"]._serialized_start = 589
    _globals["_HEALTHRESPONSE"]._serialized_end = 634
    _globals["_MESSAGINGGATEWAY"]._serialized_start = 716
    _globals["_MESSAGINGGATEWAY"]._serialized_end = 1013
# @@protoc_insertion_point(module_scope)
